@@ -28,4 +28,9 @@ class StringUtil(object):
         s = StringUtil.and_pattern.sub('-and-', s)
         s = StringUtil.at_pattern.sub('-at-', s)
         s = StringUtil.hyphen_pattern.sub('-', s)
-        return s
\ No newline at end of file
+        return s
+
+    @staticmethod
+    def slug_words(slug):
+        """extract words from slug, separated by whitespaces"""
+        return slug.replace('-and-', '-').replace('-at-', '-').replace('-', ' ')
\ No newline at end of file
